clojask.aggregate.aggre-onyx-comps


catalogclj


catalog-genclj

(catalog-gen num-work batch-size)

Generate the catalog for running Onyx

Generate the catalog for running Onyx
raw docstring

config-envclj

(config-env)

dataframeclj


envclj


env-configclj


flow-cond-genclj

(flow-cond-gen num-work)

Generate the flow conditions for running Onyx

Generate the flow conditions for running Onyx
raw docstring

flow-conditionsclj


idclj


in-callsclj


inject-in-readerclj

(inject-in-reader event lifecycle)

lifecycle-genclj

(lifecycle-gen source dist)

lifecyclesclj


n-peersclj


num-workersclj


peer-configclj


peer-groupclj


shutdownclj

(shutdown)

start-onyx-aggreclj

(start-onyx-aggre num-work
                  batch-size
                  dataframe
                  source
                  dist
                  exception
                  aggre-func
                  index
                  formatter
                  out)

start the onyx cluster with the specification inside dataframe

start the onyx cluster with the specification inside dataframe
raw docstring

v-peersclj


worker-funcclj

(worker-func seq)

worker-func-genclj

(worker-func-gen df exception aggre-funcs index formatter source)

workflowclj


workflow-genclj

(workflow-gen num-work)

Generate workflow for running Onyx

Generate workflow for running Onyx
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries