clojask.api.gb-aggregate


countclj

(count list)
source

largest3clj

(largest3 list)

return the largest 3 entries

return the largest 3 entries
sourceraw docstring

largestkclj

(largestk list k)

return the largest k entries (the performance is better with smaller k)

return the largest k entries (the performance is better with smaller k)
sourceraw docstring

maxclj

(max list)
source

meanclj

(mean list)
source

medianclj

(median list)
source

minclj

(min list)
source

modeclj

(mode list)
source

sdclj

(sd list)
source

skewclj

(skew list)

Pearson's second skewness coefficient, 3 (mean - median) / sd. NaN when all values are equal (sd is zero, or only rounding noise for doubles), for example in a group of one row.

Pearson's second skewness coefficient, 3 (mean - median) / sd. NaN when
all values are equal (sd is zero, or only rounding noise for doubles),
for example in a group of one row.
sourceraw docstring

smallest3clj

(smallest3 list)

return the smallest 3 entries

return the smallest 3 entries
sourceraw docstring

smallestkclj

(smallestk list k)

return the smallest k entries (the performance is better with smaller k)

return the smallest k entries (the performance is better with smaller k)
sourceraw docstring

sumclj

(sum list)
source

cljdoc builds & hosts documentation for Clojure/Script libraries