clojask.groupby

Utility functions to group by and aggregate.

Utility functions to group by and aggregate.
raw docstring

gen-groupby-filenamesclj

(gen-groupby-filenames dist msg groupby-keys key-index formatters)

The group key of a row: a file path under dist when dist is a directory path, otherwise the printed key vector.

The group key of a row: a file path under dist when dist is a directory
path, otherwise the printed key vector.
sourceraw docstring

output-groupbyclj

(output-groupby dist msg groupby-keys key-index formatter write-index _format)

Write one row to its group: appended to the group's file when dist is a directory path, otherwise added to dist, an in-memory MGroup.

Write one row to its group: appended to the group's file when dist is a
directory path, otherwise added to dist, an in-memory MGroup.
sourceraw docstring

read-csv-seqclj

(read-csv-seq filename)

Read all rows of a group file (a path or a reader) and close it.

Read all rows of a group file (a path or a reader) and close it.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries