clojask.join.outer-onyx-comps


catalogclj

source

catalog-genclj

(catalog-gen num-work batch-size)

Generate the catalog for running Onyx

Generate the catalog for running Onyx
sourceraw docstring

dataframeclj

source

flow-cond-genclj

(flow-cond-gen num-work)

Generate the flow conditions for running Onyx

Generate the flow conditions for running Onyx
sourceraw docstring

flow-conditionsclj

source

in-callsclj

source

inject-in-readerclj

(inject-in-reader event lifecycle)
source

lifecycle-genclj

(lifecycle-gen source dist)
source

lifecyclesclj

source

start-onyx-outerclj

(start-onyx-outer num-work
                  batch-size
                  a
                  b
                  mgroup-a
                  mgroup-b
                  dist
                  exception
                  a-index
                  b-index
                  a-format
                  b-format
                  write-index
                  output)

start the onyx cluster with the specification inside dataframe

start the onyx cluster with the specification inside dataframe
sourceraw docstring

worker-funcclj

(worker-func seq)
source

worker-func-genclj

(worker-func-gen a
                 b
                 mgroup-a
                 mgroup-b
                 exception
                 a-index
                 b-index
                 a-format
                 b-format
                 write-index)
source

worker-func-gen2clj

(worker-func-gen2 a
                  b
                  mgroup-a
                  mgroup-b
                  exception
                  a-index
                  b-index
                  a-format
                  b-format
                  write-index)
source

cljdoc builds & hosts documentation for Clojure/Script libraries