(catalog-gen num-work batch-size)Generate the catalog for running Onyx
Generate the catalog for running Onyx
(config-env)(flow-cond-gen num-work)Generate the flow conditions for running Onyx
Generate the flow conditions for running Onyx
(inject-in-reader event lifecycle)(lifecycle-gen source dist)(shutdown)(start-onyx-aggre num-work
batch-size
dataframe
source
dist
exception
aggre-func
index
formatter
out)start the onyx cluster with the specification inside dataframe
start the onyx cluster with the specification inside dataframe
(worker-func seq)(worker-func-gen df exception aggre-funcs index formatter source)(workflow-gen num-work)Generate workflow for running Onyx
Generate workflow for running Onyx
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |