clojask.groupby


gen-groupby-filenamesclj

(gen-groupby-filenames dist msg groupby-keys key-index formatters)

internal function to generate files csv line with groupby key(s)

internal function to generate files csv line with groupby key(s)
sourceraw docstring

output-groupbyclj

(output-groupby dist msg groupby-keys key-index formatter write-index _format)

internal function called by output when aggregation is applied

internal function called by output when aggregation is applied
sourceraw docstring

read-csv-seqclj

(read-csv-seq filename)

takes file name and reads data

takes file name and reads data
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries