clojask.join.outer-onyx-comps


catalogclj


catalog-genclj

(catalog-gen num-work batch-size)

Generate the catalog for running Onyx

Generate the catalog for running Onyx
raw docstring

config-envclj

(config-env)

dataframeclj


envclj


env-configclj


flow-cond-genclj

(flow-cond-gen num-work)

Generate the flow conditions for running Onyx

Generate the flow conditions for running Onyx
raw docstring

flow-conditionsclj


idclj


in-callsclj


inject-in-readerclj

(inject-in-reader event lifecycle)

lifecycle-genclj

(lifecycle-gen source dist)

lifecyclesclj


n-peersclj


num-workersclj


peer-configclj


peer-groupclj


shutdownclj

(shutdown)

start-onyx-outerclj

(start-onyx-outer num-work
                  batch-size
                  a
                  b
                  mgroup-a
                  mgroup-b
                  dist
                  exception
                  a-index
                  b-index
                  a-format
                  b-format
                  write-index
                  output)

start the onyx cluster with the specification inside dataframe

start the onyx cluster with the specification inside dataframe
raw docstring

v-peersclj


worker-funcclj

(worker-func seq)

worker-func-genclj

(worker-func-gen a
                 b
                 mgroup-a
                 mgroup-b
                 exception
                 a-index
                 b-index
                 a-format
                 b-format
                 write-index)

worker-func-gen2clj

(worker-func-gen2 a
                  b
                  mgroup-a
                  mgroup-b
                  exception
                  a-index
                  b-index
                  a-format
                  b-format
                  write-index)

workflowclj


workflow-genclj

(workflow-gen num-work)

Generate workflow for running Onyx

Generate workflow for running Onyx
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries