clojask.utils


are-inclj

(are-in cols dataframe)

return should be [] if all in

return should be [] if all in
raw docstring

are-outclj

(are-out cols dataframe)

return should be [] if all out

return should be [] if all out
raw docstring

check-duplicate-colclj

(check-duplicate-col colNames)

Check for duplicated column names and return a column names list w/o duplicates

Check for duplicated column names and return a column names list w/o duplicates
raw docstring

decode-strclj

(decode-str s)

decoderclj


encode-strclj

(encode-str s)

encoderclj


eval-resclj

(eval-res row types formats operations index)

eval-res-neclj

(eval-res-ne row types formats operations index)

filter-checkclj

(filter-check filters types row)

fromDateclj


fromStringclj


get-func-strclj

(get-func-str func)

get-keyclj

(get-key row types key-index key)

get-type-stringclj

(get-type-string x)

get-type-string-vecclj

(get-type-string-vec col)

get-valclj

(get-val row types index)

getsclj

(gets coll indices)

unlike core/get, get elements from indices

unlike core/get, get elements from indices
raw docstring

gets-formatclj

(gets-format coll indices formatters)

gets with format

gets with format
raw docstring

init-fileclj

(init-file out-dir header)

is-inclj

(is-in col dataframe)

is-outclj

(is-out col dataframe)

proc-groupby-keyclj

(proc-groupby-key input)

proc-groupby-key-eachclj

(proc-groupby-key-each pair)

set-format-stringclj

(set-format-string string)

toDateclj


toDoubleclj


toIntclj


toStringclj


type-detectionclj

(type-detection file)

type-operation-mapclj

cljdoc builds & hosts documentation for Clojure/Script libraries